@@ -4,17 +4,13 @@ use glib::translate::*;
 use std::cell::Cell;
 use std::sync::atomic::{AtomicBool, Ordering};
 
-#[cfg(target_os = "macos")]
-extern "C" {
-    fn pthread_main_np() -> i32;
-}
-
 thread_local! {
     static IS_MAIN_THREAD: Cell<bool> = Cell::new(false)
 }
 
 static INITIALIZED: AtomicBool = AtomicBool::new(false);
 
+// rustdoc-stripper-ignore-next
 /// Asserts that this is the main thread and `gtk::init` has been called.
 macro_rules! assert_initialized_main_thread {
     () => {
@@ -61,14 +57,14 @@ pub fn is_initialized_main_thread() -> bool {
 ///
 /// # Panics
 ///
-/// This function will panic if you attempt to initialise GTK from more than
+/// This function will panic if you attempt to initialize GTK from more than
 /// one thread.
 ///
 /// # Safety
 ///
 /// You must only call this if:
 ///
-/// 1. You have initialised the underlying GTK library yourself.
+/// 1. You have initialized the underlying GTK library yourself.
 /// 2. You did 1 on the thread with which you are calling this function
 /// 3. You ensure that this thread is the main thread for the process.
 pub unsafe fn set_initialized() {
@@ -77,25 +73,17 @@ pub unsafe fn set_initialized() {
         return;
     } else if is_initialized() {
         panic!("Attempted to initialize GTK from two different threads.");
+    } else if !{ from_glib(ffi::gtk_is_initialized()) } {
+        panic!("GTK was not actually initialized");
     }
-
-    //  OS X has its own notion of the main thread and init must be called on that thread.
-    #[cfg(target_os = "macos")]
-    {
-        if pthread_main_np() == 0 {
-            panic!("Attempted to initialize GTK on OSX from non-main thread");
-        }
-    }
-
-    gdk::set_initialized();
     INITIALIZED.store(true, Ordering::Release);
     IS_MAIN_THREAD.with(|c| c.set(true));
 }
 
-/// Tries to initialize GTK+.
+/// Tries to initialize GTK.
 ///
 /// Call either this function or [`Application::new`][new] before using any
-/// other GTK+ functions.
+/// other GTK functions.
 ///
 /// [new]: struct.Application.html#method.new
 ///
@@ -112,19 +100,11 @@ pub fn init() -> Result<(), glib::BoolError> {
         panic!("Attempted to initialize GTK from two different threads.");
     }
     unsafe {
-        // We just want to keep the program's name since more arguments could lead to unwanted
-        // behaviors...
-        let argv = ::std::env::args().take(1).collect::<Vec<_>>();
-
-        if from_glib(ffi::gtk_init_check(&mut 1, &mut argv.to_glib_none().0)) {
-            // See https://github.com/gtk-rs/gtk-rs-core/issues/186 for reasoning behind
-            // acquiring and leaking the main context here.
-            let result: bool = from_glib(glib::ffi::g_main_context_acquire(
-                glib::ffi::g_main_context_default(),
-            ));
-            if !result {
-                return Err(glib::bool_error!("Failed to acquire default main context"));
+        if from_glib(ffi::gtk_init_check()) {
+            if !from_glib::<glib::ffi::gboolean, bool>(ffi::gtk_is_initialized()) {
+                return Err(glib::bool_error!("GTK was not actually initialized"));
             }
+
             set_initialized();
             Ok(())
         } else {
@@ -132,15 +112,3 @@ pub fn init() -> Result<(), glib::BoolError> {
         }
     }
 }
-
-#[doc(alias = "gtk_main_quit")]
-pub fn main_quit() {
-    assert_initialized_main_thread!();
-    unsafe {
-        if ffi::gtk_main_level() > 0 {
-            ffi::gtk_main_quit();
-        } else if cfg!(debug_assertions) {
-            panic!("Attempted to quit a GTK main loop when none is running.");
-        }
-    }
-}
